@@ -132,6 +132,32 @@ impl Apps {
             since,
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List installations for the authenticated app.
+     *
+     * This function performs a `GET` to the `/app/installations` endpoint.
+     * As opposed to `apps_list_installations`, this function returns all the pages of the request at once.
+     *
+     * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
+     *
+     * The permissions the installation has are included under the `permissions` key.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-installations-for-the-authenticated-app>
+     */
+    pub async fn list_all_installations(
+        &self,
+        since: chrono::DateTime<chrono::Utc>,
+        outdated: &str,
+    ) -> Result<Vec<crate::types::Installation>> {
+        let url = format!(
+            "/app/installations?outdated={}&since={}",
+            outdated.to_string(),
+            since,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -592,7 +618,7 @@ impl Apps {
         &self,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetAppsListInstallationReposOkResponse> {
+    ) -> Result<crate::types::AppsListInstallationReposResponse> {
         let url = format!(
             "/installation/repositories?page={}&per_page={}",
             format!("{}", page),
@@ -674,6 +700,23 @@ impl Apps {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List plans.
+     *
+     * This function performs a `GET` to the `/marketplace_listing/plans` endpoint.
+     * As opposed to `apps_list_plans`, this function returns all the pages of the request at once.
+     *
+     * Lists all plans that are part of your GitHub Marketplace listing.
+     *
+     * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-plans>
+     */
+    pub async fn list_all_plans(&self) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
+        let url = "/marketplace_listing/plans".to_string();
         self.client.get_all_pages(&url).await
     }
 
@@ -713,6 +756,34 @@ impl Apps {
             sort,
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List accounts for a plan.
+     *
+     * This function performs a `GET` to the `/marketplace_listing/plans/{plan_id}/accounts` endpoint.
+     * As opposed to `apps_list_accounts_for_plan`, this function returns all the pages of the request at once.
+     *
+     * Returns user and organization accounts associated with the specified plan, including free plans. For per-seat pricing, you see the list of accounts that have purchased the plan, including the number of seats purchased. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
+     *
+     * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan>
+     */
+    pub async fn list_all_accounts_for_plan(
+        &self,
+        plan_id: i64,
+        sort: crate::types::Sort,
+        direction: crate::types::Direction,
+    ) -> Result<Vec<crate::types::MarketplacePurchase>> {
+        let url = format!(
+            "/marketplace_listing/plans/{}/accounts?direction={}&sort={}",
+            crate::progenitor_support::encode_path(&plan_id.to_string()),
+            direction,
+            sort,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -770,6 +841,25 @@ impl Apps {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List plans (stubbed).
+     *
+     * This function performs a `GET` to the `/marketplace_listing/stubbed/plans` endpoint.
+     * As opposed to `apps_list_plans_stubbed`, this function returns all the pages of the request at once.
+     *
+     * Lists all plans that are part of your GitHub Marketplace listing.
+     *
+     * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-plans-stubbed>
+     */
+    pub async fn list_all_plans_stubbed(
+        &self,
+    ) -> Result<Vec<crate::types::MarketplaceListingPlan>> {
+        let url = "/marketplace_listing/stubbed/plans".to_string();
         self.client.get_all_pages(&url).await
     }
 
@@ -810,6 +900,34 @@ impl Apps {
             sort,
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List accounts for a plan (stubbed).
+     *
+     * This function performs a `GET` to the `/marketplace_listing/stubbed/plans/{plan_id}/accounts` endpoint.
+     * As opposed to `apps_list_accounts_for_plan_stubbed`, this function returns all the pages of the request at once.
+     *
+     * Returns repository and organization accounts associated with the specified plan, including free plans. For per-seat pricing, you see the list of accounts that have purchased the plan, including the number of seats purchased. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
+     *
+     * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan-stubbed>
+     */
+    pub async fn list_all_accounts_for_plan_stubbed(
+        &self,
+        plan_id: i64,
+        sort: crate::types::Sort,
+        direction: crate::types::Direction,
+    ) -> Result<Vec<crate::types::MarketplacePurchase>> {
+        let url = format!(
+            "/marketplace_listing/stubbed/plans/{}/accounts?direction={}&sort={}",
+            crate::progenitor_support::encode_path(&plan_id.to_string()),
+            direction,
+            sort,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -932,7 +1050,7 @@ impl Apps {
         &self,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetAppsListInstallationsOkResponse> {
+    ) -> Result<crate::types::AppsListInstallationsResponse> {
         let url = format!(
             "/user/installations?page={}&per_page={}",
             format!("{}", page),
@@ -968,7 +1086,7 @@ impl Apps {
         installation_id: i64,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetAppsListInstallationReposOkResponse> {
+    ) -> Result<crate::types::AppsListInstallationReposResponse> {
         let url = format!(
             "/user/installations/{}/repositories?page={}&per_page={}",
             crate::progenitor_support::encode_path(&installation_id.to_string()),
@@ -1064,6 +1182,23 @@ impl Apps {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List subscriptions for the authenticated user.
+     *
+     * This function performs a `GET` to the `/user/marketplace_purchases` endpoint.
+     * As opposed to `apps_list_subscriptions_for_authenticated_user`, this function returns all the pages of the request at once.
+     *
+     * Lists the active subscriptions for the authenticated user. You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint. . OAuth Apps must authenticate using an [OAuth token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/).
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user>
+     */
+    pub async fn list_all_subscriptions_for_authenticated_user(
+        &self,
+    ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
+        let url = "/user/marketplace_purchases".to_string();
         self.client.get_all_pages(&url).await
     }
 
@@ -1092,6 +1227,23 @@ impl Apps {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List subscriptions for the authenticated user (stubbed).
+     *
+     * This function performs a `GET` to the `/user/marketplace_purchases/stubbed` endpoint.
+     * As opposed to `apps_list_subscriptions_for_authenticated_user_stubbed`, this function returns all the pages of the request at once.
+     *
+     * Lists the active subscriptions for the authenticated user. You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint. . OAuth Apps must authenticate using an [OAuth token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/).
+     *
+     * FROM: <https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user-stubbed>
+     */
+    pub async fn list_all_subscriptions_for_authenticated_user_stubbed(
+        &self,
+    ) -> Result<Vec<crate::types::UserMarketplacePurchase>> {
+        let url = "/user/marketplace_purchases/stubbed".to_string();
         self.client.get_all_pages(&url).await
     }
 
