@@ -156,6 +156,32 @@ impl Checks {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List check run annotations.
+     *
+     * This function performs a `GET` to the `/repos/{owner}/{repo}/check-runs/{check_run_id}/annotations` endpoint.
+     * As opposed to `checks_list_annotations`, this function returns all the pages of the request at once.
+     *
+     * Lists annotations for a check run using the annotation `id`. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get annotations for a check run. OAuth Apps and authenticated users must have the `repo` scope to get annotations for a check run in a private repository.
+     *
+     * FROM: <https://docs.github.com/rest/reference/checks#list-check-run-annotations>
+     */
+    pub async fn list_all_annotations(
+        &self,
+        owner: &str,
+        repo: &str,
+        check_run_id: i64,
+    ) -> Result<Vec<crate::types::CheckAnnotation>> {
+        let url = format!(
+            "/repos/{}/{}/check-runs/{}/annotations",
+            crate::progenitor_support::encode_path(&owner.to_string()),
+            crate::progenitor_support::encode_path(&repo.to_string()),
+            crate::progenitor_support::encode_path(&check_run_id.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -294,7 +320,7 @@ impl Checks {
         filter: crate::types::ActionsListJobsWorkflowRunFilter,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetChecksListRefOkResponse> {
+    ) -> Result<crate::types::ChecksListRefResponse> {
         let url = format!(
             "/repos/{}/{}/check-suites/{}/check-runs?check_name={}&filter={}&page={}&per_page={}&\
              status={}",
@@ -378,7 +404,7 @@ impl Checks {
         per_page: i64,
         page: i64,
         app_id: i64,
-    ) -> Result<crate::types::GetChecksListRefOkResponse> {
+    ) -> Result<crate::types::ChecksListRefResponse> {
         let url = format!(
             "/repos/{}/{}/commits/{}/check-runs?app_id={}&check_name={}&filter={}&page={}&\
              per_page={}&status={}",
@@ -426,7 +452,7 @@ impl Checks {
         check_name: &str,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetChecksListSuitesRefOkResponse> {
+    ) -> Result<crate::types::ChecksListSuitesRefResponse> {
         let url = format!(
             "/repos/{}/{}/commits/{}/check-suites?app_id={}&check_name={}&page={}&per_page={}",
             crate::progenitor_support::encode_path(&owner.to_string()),
