@@ -94,8 +94,7 @@ impl EnterpriseAdmin {
         enterprise: &str,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetEnterpriseAdminListOrgAccessSelfHostedRunnerGroupInOkResponse>
-    {
+    ) -> Result<crate::types::EnterpriseAdminListOrgAccessSelfHostedRunnerGroupInResponse> {
         let url = format!(
             "/enterprises/{}/actions/permissions/organizations?page={}&per_page={}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
@@ -281,7 +280,7 @@ impl EnterpriseAdmin {
         enterprise: &str,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetEnterpriseAdminListSelfHostedRunnerGroupsOkResponse> {
+    ) -> Result<crate::types::EnterpriseAdminListSelfHostedRunnerGroupsResponse> {
         let url = format!(
             "/enterprises/{}/actions/runner-groups?page={}&per_page={}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
@@ -445,8 +444,7 @@ impl EnterpriseAdmin {
         runner_group_id: i64,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetEnterpriseAdminListOrgAccessSelfHostedRunnerGroupInOkResponse>
-    {
+    ) -> Result<crate::types::EnterpriseAdminListOrgAccessSelfHostedRunnerGroupInResponse> {
         let url = format!(
             "/enterprises/{}/actions/runner-groups/{}/organizations?page={}&per_page={}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
@@ -584,7 +582,7 @@ impl EnterpriseAdmin {
         runner_group_id: i64,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetActionsListSelfHostedRunnersInGroupOrgOkResponse> {
+    ) -> Result<crate::types::ActionsListSelfHostedRunnersInGroupOrgResponse> {
         let url = format!(
             "/enterprises/{}/actions/runner-groups/{}/runners?page={}&per_page={}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
@@ -721,7 +719,7 @@ impl EnterpriseAdmin {
         enterprise: &str,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetEnterpriseAdminListSelfHostedRunnersOkResponse> {
+    ) -> Result<crate::types::EnterpriseAdminListSelfHostedRunnersResponse> {
         let url = format!(
             "/enterprises/{}/actions/runners?page={}&per_page={}",
             crate::progenitor_support::encode_path(&enterprise.to_string()),
@@ -756,6 +754,30 @@ impl EnterpriseAdmin {
             crate::progenitor_support::encode_path(&enterprise.to_string()),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List runner applications for an enterprise.
+     *
+     * This function performs a `GET` to the `/enterprises/{enterprise}/actions/runners/downloads` endpoint.
+     * As opposed to `enterprise_admin_list_runner_applications_for_enterprise`, this function returns all the pages of the request at once.
+     *
+     * Lists binaries for the runner application that you can download and run.
+     *
+     * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/enterprise-admin#list-runner-applications-for-an-enterprise>
+     */
+    pub async fn list_all_runner_applications_for_enterprise(
+        &self,
+        enterprise: &str,
+    ) -> Result<Vec<crate::types::RunnerApplication>> {
+        let url = format!(
+            "/enterprises/{}/actions/runners/downloads",
+            crate::progenitor_support::encode_path(&enterprise.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -942,6 +964,38 @@ impl EnterpriseAdmin {
             phrase.to_string(),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * Get the audit log for an enterprise.
+     *
+     * This function performs a `GET` to the `/enterprises/{enterprise}/audit-log` endpoint.
+     * As opposed to `enterprise_admin_get_audit_log`, this function returns all the pages of the request at once.
+     *
+     * Gets the audit log for an enterprise. To use this endpoint, you must be an enterprise admin, and you must use an access token with the `admin:enterprise` scope.
+     *
+     * FROM: <https://docs.github.com/rest/reference/enterprise-admin#get-the-audit-log-for-an-enterprise>
+     */
+    pub async fn get_all_audit_log(
+        &self,
+        enterprise: &str,
+        phrase: &str,
+        include: crate::types::Include,
+        after: &str,
+        before: &str,
+        order: crate::types::Order,
+    ) -> Result<Vec<crate::types::AuditLogEvent>> {
+        let url = format!(
+            "/enterprises/{}/audit-log?after={}&before={}&include={}&order={}&phrase={}",
+            crate::progenitor_support::encode_path(&enterprise.to_string()),
+            after.to_string(),
+            before.to_string(),
+            include,
+            order,
+            phrase.to_string(),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
