@@ -39,6 +39,24 @@ impl Orgs {
             format!("{}", since),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organizations.
+     *
+     * This function performs a `GET` to the `/organizations` endpoint.
+     * As opposed to `orgs_list`, this function returns all the pages of the request at once.
+     *
+     * Lists all organizations, in the order that they were created on GitHub.
+     *
+     * **Note:** Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of organizations.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organizations>
+     */
+    pub async fn list_all(&self, since: i64) -> Result<Vec<crate::types::OrganizationSimple>> {
+        let url = format!("/organizations?since={}", format!("{}", since),);
+
         self.client.get_all_pages(&url).await
     }
 
@@ -153,6 +171,40 @@ impl Orgs {
             phrase.to_string(),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * Get the audit log for an organization.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/audit-log` endpoint.
+     * As opposed to `orgs_get_audit_log`, this function returns all the pages of the request at once.
+     *
+     * Gets the audit log for an organization. For more information, see "[Reviewing the audit log for your organization](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/reviewing-the-audit-log-for-your-organization)."
+     *
+     * To use this endpoint, you must be an organization owner, and you must use an access token with the `admin:org` scope. GitHub Apps must have the `organization_administration` read permission to use this endpoint.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#get-audit-log>
+     */
+    pub async fn get_all_audit_log(
+        &self,
+        org: &str,
+        phrase: &str,
+        include: crate::types::Include,
+        after: &str,
+        before: &str,
+        order: crate::types::Order,
+    ) -> Result<Vec<crate::types::AuditLogEvent>> {
+        let url = format!(
+            "/orgs/{}/audit-log?after={}&before={}&include={}&order={}&phrase={}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            after.to_string(),
+            before.to_string(),
+            include,
+            order,
+            phrase.to_string(),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -175,6 +227,25 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List users blocked by an organization.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/blocks` endpoint.
+     * As opposed to `orgs_list_blocked_users`, this function returns all the pages of the request at once.
+     *
+     * List the users blocked by an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-users-blocked-by-an-organization>
+     */
+    pub async fn list_all_blocked_users(&self, org: &str) -> Result<Vec<crate::types::User>> {
+        let url = format!(
+            "/orgs/{}/blocks",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -274,6 +345,30 @@ impl Orgs {
             crate::progenitor_support::encode_path(&org.to_string()),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List SAML SSO authorizations for an organization.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/credential-authorizations` endpoint.
+     * As opposed to `orgs_list_saml_sso_authorizations`, this function returns all the pages of the request at once.
+     *
+     * Listing and deleting credential authorizations is available to organizations with GitHub Enterprise Cloud. For more information, see [GitHub's products](https://help.github.com/github/getting-started-with-github/githubs-products).
+     *
+     * An authenticated organization owner with the `read:org` scope can list all credential authorizations for an organization that uses SAML single sign-on (SSO). The credentials are either personal access tokens or SSH keys that organization members have authorized for the organization. For more information, see [About authentication with SAML single sign-on](https://help.github.com/en/articles/about-authentication-with-saml-single-sign-on).
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-saml-sso-authorizations-for-an-organization>
+     */
+    pub async fn list_all_saml_sso_authorizations(
+        &self,
+        org: &str,
+    ) -> Result<Vec<crate::types::CredentialAuthorization>> {
+        let url = format!(
+            "/orgs/{}/credential-authorizations",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -331,6 +426,28 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List failed organization invitations.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/failed_invitations` endpoint.
+     * As opposed to `orgs_list_failed_invitations`, this function returns all the pages of the request at once.
+     *
+     * The return hash contains `failed_at` and `failed_reason` fields which represent the time at which the invitation failed and the reason for the failure.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-failed-organization-invitations>
+     */
+    pub async fn list_all_failed_invitations(
+        &self,
+        org: &str,
+    ) -> Result<Vec<crate::types::OrganizationInvitation>> {
+        let url = format!(
+            "/orgs/{}/failed_invitations",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -362,6 +479,25 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organization webhooks.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/hooks` endpoint.
+     * As opposed to `orgs_list_webhooks`, this function returns all the pages of the request at once.
+     *
+     *
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organization-webhooks>
+     */
+    pub async fn list_all_webhooks(&self, org: &str) -> Result<Vec<crate::types::OrgHook>> {
+        let url = format!(
+            "/orgs/{}/hooks",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -588,7 +724,7 @@ impl Orgs {
         org: &str,
         per_page: i64,
         page: i64,
-    ) -> Result<crate::types::GetAppsListInstallationsOkResponse> {
+    ) -> Result<crate::types::AppsListInstallationsResponse> {
         let url = format!(
             "/orgs/{}/installations?page={}&per_page={}",
             crate::progenitor_support::encode_path(&org.to_string()),
@@ -627,6 +763,28 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List pending organization invitations.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/invitations` endpoint.
+     * As opposed to `orgs_list_pending_invitations`, this function returns all the pages of the request at once.
+     *
+     * The return hash contains a `role` field which refers to the Organization Invitation role and will be one of the following values: `direct_member`, `admin`, `billing_manager`, `hiring_manager`, or `reinstate`. If the invitee is not a GitHub member, the `login` field in the return hash will be `null`.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-pending-organization-invitations>
+     */
+    pub async fn list_all_pending_invitations(
+        &self,
+        org: &str,
+    ) -> Result<Vec<crate::types::OrganizationInvitation>> {
+        let url = format!(
+            "/orgs/{}/invitations",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -720,6 +878,30 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organization invitation teams.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/invitations/{invitation_id}/teams` endpoint.
+     * As opposed to `orgs_list_invitation_teams`, this function returns all the pages of the request at once.
+     *
+     * List all teams associated with an invitation. In order to see invitations in an organization, the authenticated user must be an organization owner.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organization-invitation-teams>
+     */
+    pub async fn list_all_invitation_teams(
+        &self,
+        org: &str,
+        invitation_id: i64,
+    ) -> Result<Vec<crate::types::Team>> {
+        let url = format!(
+            "/orgs/{}/invitations/{}/teams",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&invitation_id.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -762,6 +944,32 @@ impl Orgs {
             role,
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organization members.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/members` endpoint.
+     * As opposed to `orgs_list_members`, this function returns all the pages of the request at once.
+     *
+     * List all users who are members of an organization. If the authenticated user is also a member of this organization then both concealed and public members will be returned.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organization-members>
+     */
+    pub async fn list_all_members(
+        &self,
+        org: &str,
+        filter: crate::types::OrgsListMembersFilter,
+        role: crate::types::OrgsListMembersRole,
+    ) -> Result<Vec<crate::types::User>> {
+        let url = format!(
+            "/orgs/{}/members?filter={}&role={}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            filter,
+            role,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -942,6 +1150,30 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List outside collaborators for an organization.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/outside_collaborators` endpoint.
+     * As opposed to `orgs_list_outside_collaborators`, this function returns all the pages of the request at once.
+     *
+     * List all users who are outside collaborators of an organization.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-outside-collaborators-for-an-organization>
+     */
+    pub async fn list_all_outside_collaborators(
+        &self,
+        org: &str,
+        filter: crate::types::OrgsListMembersFilter,
+    ) -> Result<Vec<crate::types::User>> {
+        let url = format!(
+            "/orgs/{}/outside_collaborators?filter={}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            filter,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -1025,6 +1257,25 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List public organization members.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/public_members` endpoint.
+     * As opposed to `orgs_list_public_members`, this function returns all the pages of the request at once.
+     *
+     * Members of an organization can choose to have their membership publicized or not.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-public-organization-members>
+     */
+    pub async fn list_all_public_members(&self, org: &str) -> Result<Vec<crate::types::User>> {
+        let url = format!(
+            "/orgs/{}/public_members",
+            crate::progenitor_support::encode_path(&org.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -1138,6 +1389,25 @@ impl Orgs {
             state,
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organization memberships for the authenticated user.
+     *
+     * This function performs a `GET` to the `/user/memberships/orgs` endpoint.
+     * As opposed to `orgs_list_memberships_for_authenticated_user`, this function returns all the pages of the request at once.
+     *
+     *
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user>
+     */
+    pub async fn list_all_memberships_for_authenticated_user(
+        &self,
+        state: crate::types::OrgMembershipState,
+    ) -> Result<Vec<crate::types::OrgMembership>> {
+        let url = format!("/user/memberships/orgs?state={}", state,);
+
         self.client.get_all_pages(&url).await
     }
 
@@ -1226,6 +1496,27 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organizations for the authenticated user.
+     *
+     * This function performs a `GET` to the `/user/orgs` endpoint.
+     * As opposed to `orgs_list_for_authenticated_user`, this function returns all the pages of the request at once.
+     *
+     * List organizations for the authenticated user.
+     *
+     * **OAuth scope requirements**
+     *
+     * This only lists organizations that your authorization allows you to operate on in some way (e.g., you can list teams with `read:org` scope, you can publicize your organization membership with `user` scope, etc.). Therefore, this API requires at least `user` or `read:org` scope. OAuth requests with insufficient scope receive a `403 Forbidden` response.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user>
+     */
+    pub async fn list_all_for_authenticated_user(
+        &self,
+    ) -> Result<Vec<crate::types::OrganizationSimple>> {
+        let url = "/user/orgs".to_string();
         self.client.get_all_pages(&url).await
     }
 
@@ -1259,6 +1550,30 @@ impl Orgs {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List organizations for a user.
+     *
+     * This function performs a `GET` to the `/users/{username}/orgs` endpoint.
+     * As opposed to `orgs_list_for_user`, this function returns all the pages of the request at once.
+     *
+     * List [public organization memberships](https://help.github.com/articles/publicizing-or-concealing-organization-membership) for the specified user.
+     *
+     * This method only lists _public_ memberships, regardless of authentication. If you need to fetch all of the organization memberships (public and private) for the authenticated user, use the [List organizations for the authenticated user](https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user) API instead.
+     *
+     * FROM: <https://docs.github.com/rest/reference/orgs#list-organizations-for-a-user>
+     */
+    pub async fn list_all_for_user(
+        &self,
+        username: &str,
+    ) -> Result<Vec<crate::types::OrganizationSimple>> {
+        let url = format!(
+            "/users/{}/orgs",
+            crate::progenitor_support::encode_path(&username.to_string()),
+        );
+
         self.client.get_all_pages(&url).await
     }
 }
