@@ -54,6 +54,38 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a team discussion comment.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/comments/{comment_number}/reactions` endpoint.
+     * As opposed to `reactions_list_for_team_discussion_comment_in_org`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments/). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
+     *
+     * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions`.
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment>
+     */
+    pub async fn list_all_for_team_discussion_comment_in_org(
+        &self,
+        org: &str,
+        team_slug: &str,
+        discussion_number: i64,
+        comment_number: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/orgs/{}/teams/{}/discussions/{}/comments/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&team_slug.to_string()),
+            crate::progenitor_support::encode_path(&discussion_number.to_string()),
+            crate::progenitor_support::encode_path(&comment_number.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -177,6 +209,36 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a team discussion.
+     *
+     * This function performs a `GET` to the `/orgs/{org}/teams/{team_slug}/discussions/{discussion_number}/reactions` endpoint.
+     * As opposed to `reactions_list_for_team_discussion_in_org`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
+     *
+     * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/:org_id/team/:team_id/discussions/:discussion_number/reactions`.
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion>
+     */
+    pub async fn list_all_for_team_discussion_in_org(
+        &self,
+        org: &str,
+        team_slug: &str,
+        discussion_number: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/orgs/{}/teams/{}/discussions/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&org.to_string()),
+            crate::progenitor_support::encode_path(&team_slug.to_string()),
+            crate::progenitor_support::encode_path(&discussion_number.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -316,6 +378,34 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a commit comment.
+     *
+     * This function performs a `GET` to the `/repos/{owner}/{repo}/comments/{comment_id}/reactions` endpoint.
+     * As opposed to `reactions_list_for_commit_comment`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to a [commit comment](https://docs.github.com/rest/reference/repos#comments).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-a-commit-comment>
+     */
+    pub async fn list_all_for_commit_comment(
+        &self,
+        owner: &str,
+        repo: &str,
+        comment_id: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/repos/{}/{}/comments/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&owner.to_string()),
+            crate::progenitor_support::encode_path(&repo.to_string()),
+            crate::progenitor_support::encode_path(&comment_id.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -429,6 +519,34 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for an issue comment.
+     *
+     * This function performs a `GET` to the `/repos/{owner}/{repo}/issues/comments/{comment_id}/reactions` endpoint.
+     * As opposed to `reactions_list_for_issue_comment`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to an [issue comment](https://docs.github.com/rest/reference/issues#comments).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue-comment>
+     */
+    pub async fn list_all_for_issue_comment(
+        &self,
+        owner: &str,
+        repo: &str,
+        comment_id: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/repos/{}/{}/issues/comments/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&owner.to_string()),
+            crate::progenitor_support::encode_path(&repo.to_string()),
+            crate::progenitor_support::encode_path(&comment_id.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -542,6 +660,34 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for an issue.
+     *
+     * This function performs a `GET` to the `/repos/{owner}/{repo}/issues/{issue_number}/reactions` endpoint.
+     * As opposed to `reactions_list_for_issue`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to an [issue](https://docs.github.com/rest/reference/issues).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue>
+     */
+    pub async fn list_all_for_issue(
+        &self,
+        owner: &str,
+        repo: &str,
+        issue_number: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/repos/{}/{}/issues/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&owner.to_string()),
+            crate::progenitor_support::encode_path(&repo.to_string()),
+            crate::progenitor_support::encode_path(&issue_number.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -655,6 +801,34 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a pull request review comment.
+     *
+     * This function performs a `GET` to the `/repos/{owner}/{repo}/pulls/comments/{comment_id}/reactions` endpoint.
+     * As opposed to `reactions_list_for_pull_request_review_comment`, this function returns all the pages of the request at once.
+     *
+     * List the reactions to a [pull request review comment](https://docs.github.com/rest/reference/pulls#review-comments).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-review-comment>
+     */
+    pub async fn list_all_for_pull_request_review_comment(
+        &self,
+        owner: &str,
+        repo: &str,
+        comment_id: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/repos/{}/{}/pulls/comments/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&owner.to_string()),
+            crate::progenitor_support::encode_path(&repo.to_string()),
+            crate::progenitor_support::encode_path(&comment_id.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -807,6 +981,36 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a team discussion comment (Legacy).
+     *
+     * This function performs a `GET` to the `/teams/{team_id}/discussions/{discussion_number}/comments/{comment_number}/reactions` endpoint.
+     * As opposed to `reactions_list_for_team_discussion_comment_legacy`, this function returns all the pages of the request at once.
+     *
+     * **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List reactions for a team discussion comment`](https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment) endpoint.
+     *
+     * List the reactions to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-comment-legacy>
+     */
+    pub async fn list_all_for_team_discussion_comment_legacy(
+        &self,
+        team_id: i64,
+        discussion_number: i64,
+        comment_number: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/teams/{}/discussions/{}/comments/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&team_id.to_string()),
+            crate::progenitor_support::encode_path(&discussion_number.to_string()),
+            crate::progenitor_support::encode_path(&comment_number.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
@@ -885,6 +1089,34 @@ impl Reactions {
             format!("{}", per_page),
         );
 
+        self.client.get(&url).await
+    }
+
+    /**
+     * List reactions for a team discussion (Legacy).
+     *
+     * This function performs a `GET` to the `/teams/{team_id}/discussions/{discussion_number}/reactions` endpoint.
+     * As opposed to `reactions_list_for_team_discussion_legacy`, this function returns all the pages of the request at once.
+     *
+     * **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List reactions for a team discussion`](https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion) endpoint.
+     *
+     * List the reactions to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
+     *
+     * FROM: <https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-legacy>
+     */
+    pub async fn list_all_for_team_discussion_legacy(
+        &self,
+        team_id: i64,
+        discussion_number: i64,
+        content: crate::types::Content,
+    ) -> Result<Vec<crate::types::Reaction>> {
+        let url = format!(
+            "/teams/{}/discussions/{}/reactions?content={}",
+            crate::progenitor_support::encode_path(&team_id.to_string()),
+            crate::progenitor_support::encode_path(&discussion_number.to_string()),
+            content,
+        );
+
         self.client.get_all_pages(&url).await
     }
 
